/*
 * Copyright (c) 2022-2023 NVIDIA CORPORATION & AFFILIATES, ALL RIGHTS RESERVED.
 *
 * This software product is a proprietary product of NVIDIA CORPORATION &
 * AFFILIATES (the "Company") and all right, title, and interest in and to the
 * software product, including all associated intellectual property rights, are
 * and shall remain exclusively with the Company.
 *
 * This software product is governed by the End User License Agreement
 * provided with the software product.
 *
 */

#include <doca_log.h>

#include "rmax_common.h"

DOCA_LOG_REGISTER(RMAX_SET_AFFINITY::MAIN);

/* Sample's logic */
doca_error_t set_affinity(void);

/*
 * Sample main function
 *
 * @argc [in]: command line arguments size
 * @argv [in]: array of command line arguments
 * @return: EXIT_SUCCESS on success and EXIT_FAILURE otherwise
 */
int
main(int argc, char **argv)
{
	doca_error_t result;
	int exit_status = EXIT_SUCCESS;
	struct doca_logger_backend *stdout_logger = NULL;

	/* Create a logger backend that prints to the standard output */
	result = doca_log_create_file_backend(stdout, &stdout_logger);
	if (result != DOCA_SUCCESS)
		return EXIT_FAILURE;

	result = set_affinity();
	if (result != DOCA_SUCCESS) {
		DOCA_LOG_ERR("set_affinity() sample encountered errors: %s", doca_get_error_name(result));
		exit_status = EXIT_FAILURE;
	}

	return exit_status;
}
